RangersApplogAutoTrackPageConfig<T extends Widget> class

Constructors

RangersApplogAutoTrackPageConfig({String? pageID, String? pagePath, bool ignore = false, String? pageTitle})

Properties

hashCode int
The hash code for this object.
no setterinherited
ignore bool
getter/setter pair
pageID String?
getter/setter pair
pagePath String?
getter/setter pair
pageTitle String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

isPageWidget(Widget pageWidget) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited